package javax.swing.text.html;

import java.awt.Container;
import java.awt.Font;
import javax.swing.text.View;
import javax.swing.text.Document;
import java.awt.Toolkit;
import javax.swing.text.StyledDocument;
import javax.swing.text.StyleConstants;
import javax.swing.text.Element;

class LineView extends ParagraphView
{
    int tabBase;
    
    public LineView(Element element) {
        super(element);
    }
    
    @Override
    public boolean isVisible() {
        return true;
    }
    
    @Override
    public float getMinimumSpan(int n) {
        return this.getPreferredSpan(n);
    }
    
    @Override
    public int getResizeWeight(int i) {
        switch (i) {
            case 0: {
                return 1;
            }
            case 1: {
                return 0;
            }
            default: {
                throw new IllegalArgumentException("Invalid axis: " + i);
            }
        }
    }
    
    @Override
    public float getAlignment(int axis) {
        if (axis == 0) {
            return 0.0f;
        }
        return super.getAlignment(axis);
    }
    
    @Override
    protected void layout(int n, int height) {
        super.layout(2147483646, height);
    }
    
    @Override
    public float nextTabStop(float x, int tabOffset) {
        if (this.getTabSet() == null && StyleConstants.getAlignment(this.getAttributes()) == 0) {
            return this.getPreTab(x, tabOffset);
        }
        return super.nextTabStop(x, tabOffset);
    }
    
    protected float getPreTab(float n, int pos) {
        Document document = this.getDocument();
        View viewAtPosition = this.getViewAtPosition(pos, null);
        if (document instanceof StyledDocument && viewAtPosition != null) {
            Font font = ((StyledDocument)document).getFont(viewAtPosition.getAttributes());
            Container container = this.getContainer();
            int n2 = this.getCharactersPerTab() * ((container != null) ? container.getFontMetrics(font) : Toolkit.getDefaultToolkit().getFontMetrics(font)).charWidth('W');
            int n3 = (int)this.getTabBase();
            return (float)((((int)n - n3) / n2 + 1) * n2 + n3);
        }
        return 10.0f + n;
    }
    
    protected int getCharactersPerTab() {
        return 8;
    }
}
